@@ -22,7 +22,7 @@ Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 #include "SplitClip.h"
 		
 #include <libtraversocore.h>
-#include <SongView.h>
+#include <SheetView.h>
 #include <AudioClipView.h>
 #include "LineView.h"
 #include <ViewItem.h>
@@ -37,13 +37,13 @@ SplitClip::SplitClip(AudioClipView* view)
 	: Command(view->get_clip(), tr("Split Clip"))
 {
 	m_clip = view->get_clip();
-	m_sv = view->get_songview();
+	m_sv = view->get_sheetview();
 	m_cv = view;
 	m_track = m_clip->get_track();
 	leftClip = 0;
 	rightClip = 0;
 	m_splitPoint = TimeRef();
-	Q_ASSERT(m_clip->get_song());
+	Q_ASSERT(m_clip->get_sheet());
 }
 
 
@@ -60,7 +60,7 @@ int SplitClip::prepare_actions()
 	leftClip = resources_manager()->get_clip(m_clip->get_id());
 	rightClip = resources_manager()->get_clip(m_clip->get_id());
 	
-	leftClip->set_song(m_clip->get_song());
+	leftClip->set_sheet(m_clip->get_sheet());
 	leftClip->set_track_start_location(m_clip->get_track_start_location());
 	leftClip->set_right_edge(m_splitPoint);
 	if (leftClip->get_fade_out()) {
@@ -69,7 +69,7 @@ int SplitClip::prepare_actions()
 		Command::process_command(cmd);
 	}
 	
-	rightClip->set_song(m_clip->get_song());
+	rightClip->set_sheet(m_clip->get_sheet());
 	rightClip->set_left_edge(m_splitPoint);
 	rightClip->set_track_start_location(m_splitPoint);
 	if (rightClip->get_fade_in()) {
@@ -147,8 +147,8 @@ int SplitClip::jog()
 
 	m_splitPoint = x * m_sv->timeref_scalefactor;
 
-	if (m_clip->get_song()->is_snap_on()) {
-		SnapList* slist = m_clip->get_song()->get_snap_list();
+	if (m_clip->get_sheet()->is_snap_on()) {
+		SnapList* slist = m_clip->get_sheet()->get_snap_list();
 		m_splitPoint = slist->get_snap_value(m_splitPoint);
 	}
 	
