@@ -1,5 +1,5 @@
 /*
-Copyright (C) 2006 Remon Sijrier 
+Copyright (C) 2017 Remon Sijrier
 
 This file is part of Traverso
 
@@ -16,8 +16,6 @@ GNU General Public License for more details.
 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
-
-$Id: Tsar.cpp,v 1.4 2008/02/11 10:11:52 r_sijrier Exp $
 */
 
 #include "Tsar.h"
@@ -148,7 +146,7 @@ void Tsar::process_events( )
 			int processtime = (int) (get_microseconds() - starttime);
 			printf("called %s::%s, (signal: %s) \n", event.caller->metaObject()->className(), 
 			(event.slotindex >= 0) ? event.caller->metaObject()->method(event.slotindex).signature() : "", 
-			(event.signalindex >= 0) ? event.caller->metaObject()->method(event.signalindex + 4).signature() : "");
+            (event.signalindex >= 0) ? event.caller->metaObject()->method(event.signalindex + event.caller->metaObject()->methodOffset()).signature() : "");
 			printf("Process time: %d useconds\n\n", processtime);
 #endif
 		}
@@ -243,13 +241,11 @@ TsarEvent Tsar::create_event( QObject* caller, void* argument, const char* slotS
 	}
 	
 	if (qstrlen(signalSignature) > 0) {
-		/* the signal index seems to have an offset of 4, so we have to substract 4 from */
-		/* the value returned by caller->metaObject()->indexOfMethod*/ 
-		index = caller->metaObject()->indexOfMethod(signalSignature) - 4;
+        index = caller->metaObject()->indexOfMethod(signalSignature) - caller->metaObject()->methodOffset();
 		if (index < 0) {
 			PWARN("Signal signature contains whitespaces, please remove to avoid unneeded processing (%s::%s)", caller->metaObject()->className(), signalSignature);
 			QByteArray norm = QMetaObject::normalizedSignature(signalSignature);
-			index = caller->metaObject()->indexOfMethod(norm.constData()) - 4;
+            index = caller->metaObject()->indexOfMethod(norm.constData()) - caller->metaObject()->methodOffset();
 		}
 		event.signalindex = index; 
 	} else {
@@ -281,7 +277,7 @@ void Tsar::process_event_slot(const TsarEvent& event )
 		// This equals QMetaObject::invokeMethod(), without type checking. But we know that the types
 		// are the correct ones, and will be casted just fine!
 		if ( ! (event.caller->qt_metacall(QMetaObject::InvokeMetaMethod, event.slotindex, _a) < 0) ) {
-			qDebug("Tsar::process_event_slot failed (%s::%s)", event.caller->metaObject()->className(), event.caller->metaObject()->method(event.slotindex).signature());
+            qDebug("Tsar::process_event_slot failed (%s::%s)", event.caller->metaObject()->className(), event.caller->metaObject()->method(event.slotindex).methodSignature());
 		}
 	}
 }
