@@ -26,6 +26,7 @@ $Id: ContextPointer.cpp,v 1.17 2007/12/15 16:50:18 r_sijrier Exp $
 #include "InputEngine.h"
 #include "Utils.h"
 #include "Themer.h"
+#include "TraversoCommands.h"
 
 
 // Always put me below _all_ includes, this is needed
@@ -60,6 +61,8 @@ $Id: ContextPointer.cpp,v 1.17 2007/12/15 16:50:18 r_sijrier Exp $
  */
 ContextPointer& cpointer()
 {
+    TraversoCommands* tCommands = new TraversoCommands();
+    ie().register_command_plugin(tCommands, "TraversoCommands");
 	static ContextPointer contextPointer;
 	return contextPointer;
 }
