@@ -17,29 +17,29 @@ You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301  USA.
 
-$Id: CurveNode.cpp,v 1.2 2006/05/17 21:59:21 r_sijrier Exp $
+$Id: CurveNode.cpp,v 1.8 2007/11/23 14:56:36 r_sijrier Exp $
 */
 
 #include "CurveNode.h"
+#include "Curve.h"
 
 // Always put me below _all_ includes, this is needed
 // in case we run with memory leak detection enabled!
 #include "Debugger.h"
 
-
-CurveNode::CurveNode(double pos, double  val)
+void CurveNode::set_relative_when_and_value( double relwhen, double value )
 {
-	PENTERCONS3;
-	coeff[0] = coeff[1] = coeff[2] = coeff[3] = 0.0;
-	
-	when = pos;
-	value = val;
+	this->when = relwhen * m_curve->get_range();
+	this->value = value;
 }
 
-CurveNode::~CurveNode()
+void CurveNode::set_when_and_value(double when, double value)
 {
-	PENTERDES3;
+	if (this->when == when && this->value == value) return;
+	this->when = when;
+	this->value = value;
+	emit m_curve->nodePositionChanged();
 }
-
-
 //eof
+
+
