@@ -1,5 +1,5 @@
 /*
-    Copyright (C) 2005-2007 Remon Sijrier
+    Copyright (C) 2005-2008 Remon Sijrier
 
     This file is part of Traverso
 
@@ -143,6 +143,7 @@ public:
         int broadcast_action_from_contextmenu(const QString& name);
 
         void jog();
+	void bypass_jog_until_mouse_movements_exceeded_manhattenlength(int length=35);
 
         void activate();
         void suspend();
@@ -159,6 +160,8 @@ public:
         void set_hold_sensitiveness(int factor);
         void set_double_fact_interval(int time);
 
+        void register_command_plugin(CommandPlugin* plugin, const QString& pluginName);
+
 
 private:
         InputEngine();
@@ -185,6 +188,8 @@ private:
         EventCatcher 		catcher;
         Command* 		holdingCommand;
         QString			sCollectedNumber;
+	QPoint			m_jogBypassPos;
+
 
         bool 			active;
         bool 			isHolding;
@@ -193,8 +198,8 @@ private:
         bool 			isFirstFact;
         bool 			isDoubleKey;
         bool 			isJogging;
-        bool 			isCollecting;
 	bool			m_cancelHold;
+	bool			m_bypassJog;
 
         int 			fact1_k1;
         int 			fact1_k2;
@@ -215,6 +220,7 @@ private:
         int 			doubleFactWaitTime;
         long 			eventTime[STACK_SIZE];
 	int			m_broadcastResult;
+	int			m_unbypassJogDistance;
 
         bool 			is_fake( int keyval);
         int 			identify_first_fact();
@@ -230,7 +236,7 @@ private:
         void 			conclusion();
         void 			hold_output();
         void 			stop_collecting();
-        void 			check_number_collection();
+        bool 			check_number_collection(int eventcode);
 
         //! call the slot that handler a given action
         int broadcast_action(IEAction* action, bool autorepeat=false, bool fromContextMenu=false);
@@ -250,8 +256,6 @@ private:
 
         // allow this function to create one instance
         friend InputEngine& ie();
-
-
 };
 
 // use this function to get the InputEngine object
