@@ -141,8 +141,8 @@ int Track::set_state( const QDomNode & node )
 	}
 	set_muted_by_solo(e.attribute( "mutedbysolo", "0").toInt());
 	set_pan( e.attribute( "pan", "" ).toFloat() );
-	set_bus_in( e.attribute( "InBus", "" ).toAscii() );
-	set_bus_out( e.attribute( "OutBus", "" ).toAscii() );
+	set_bus_in( e.attribute( "InBus", "" ).toLatin1() );
+	set_bus_out( e.attribute( "OutBus", "" ).toLatin1() );
 	m_id = e.attribute("id", "0").toLongLong();
 	if (m_id == 0) {
 		m_id = create_id();
@@ -490,7 +490,9 @@ Command* Track::solo(  )
 
 Command* Track::silence_others( )
 {
-	return new PCommand(this, "solo", tr("Silence Others"));
+    PCommand* cmd = new PCommand(this, "solo", tr("Silence Others"));
+    cmd->set_historable(false);
+    return cmd;
 }
 
 void Track::set_name( const QString & name )
