@@ -86,6 +86,10 @@ private:
 class HoldCursor : public ContextItem, public QGraphicsItem
 {
 	Q_OBJECT
+#if QT_VERSION >= 0x040600
+        Q_INTERFACES(QGraphicsItem)
+#endif
+
 public:
 	HoldCursor(ViewPort* vp);
 	~HoldCursor();
