@@ -102,8 +102,8 @@ AlsaDriver::~AlsaDriver()
 int AlsaDriver::setup(bool capture, bool playback, const QString& pcmName, const QString& ditherShape)
 {
 	unsigned long user_nperiods = device->get_driver_property("numberofperiods", 3).toInt();
-	char *playback_pcm_name = strdup(pcmName.toAscii().data());
-	char *capture_pcm_name = strdup(pcmName.toAscii().data());
+    char *playback_pcm_name = strdup(pcmName.toLatin1().data());
+    char *capture_pcm_name = strdup(pcmName.toLatin1().data());
 	int shorts_first = false;
 
 	/* duplex is the default */
@@ -1256,7 +1256,7 @@ again:
 			}
 
 			if (revents & POLLERR) {
-				xrun_detected = TRUE;
+                xrun_detected = true;
 			}
 
 			if (revents & POLLOUT) {
@@ -1280,7 +1280,7 @@ again:
 			}
 
 			if (revents & POLLERR) {
-				xrun_detected = TRUE;
+                xrun_detected = true;
 			}
 
 			if (revents & POLLIN) {
