@@ -52,11 +52,10 @@ struct PluginInfo {
 class Plugin : public ContextItem
 {
 	Q_OBJECT
-	Q_CLASSINFO("toggle_bypass", tr("Bypass: On/Off"))
 	
 public:
-	Plugin(Sheet* sheet = 0);
-	virtual ~Plugin(){};
+        Plugin(Sheet* session = 0);
+        virtual ~Plugin(){}
 
 	virtual int init() {return 1;}
 	virtual	QDomNode get_state(QDomDocument doc);
@@ -68,14 +67,14 @@ public:
 	QList<PluginControlPort* > get_control_ports() const { return m_controlPorts; }
 	
 	Plugin* get_slave() const {return m_slave;}
-	Sheet* get_sheet() const {return m_sheet;}
+        Sheet* get_sheet() const {return m_sheet;}
 	bool is_bypassed() const {return m_bypass;}
 	
 	void automate_port(int index, bool automate);
 	
 protected:
-	Plugin* m_slave;
-	Sheet* m_sheet;
+        Plugin*                         m_slave;
+        Sheet*                       m_sheet;
 	QList<PluginControlPort* > 	m_controlPorts;
 	QList<AudioInputPort* >		m_audioInputPorts;
 	QList<AudioOutputPort* >	m_audioOutputPorts;
@@ -87,7 +86,7 @@ signals:
 	void bypassChanged();
 	
 public slots:
-	Command* toggle_bypass();
+    Command* toggle_bypass();
 };
 
 
@@ -95,9 +94,9 @@ class PluginPort : public QObject
 {
 
 public:
-	PluginPort(QObject* parent, int index) : QObject(parent), m_index(index), m_hint(FLOAT_CONTROL) {};
-	PluginPort(QObject* parent) : QObject(parent), m_hint(FLOAT_CONTROL) {};
-	virtual ~PluginPort(){};
+        PluginPort(QObject* parent, int index) : QObject(parent), m_index(index), m_hint(FLOAT_CONTROL) {}
+        PluginPort(QObject* parent) : QObject(parent), m_hint(FLOAT_CONTROL) {}
+        virtual ~PluginPort(){}
 
 	virtual QDomNode get_state(QDomDocument doc);
 	virtual int set_state( const QDomNode & node ) = 0;
@@ -182,8 +181,8 @@ class AudioOutputPort : public PluginPort
 
 public:
 	AudioOutputPort(QObject* parent, int index);
-	AudioOutputPort(QObject* parent) : PluginPort(parent) {};
-	virtual ~AudioOutputPort(){};
+        AudioOutputPort(QObject* parent) : PluginPort(parent) {}
+        virtual ~AudioOutputPort(){}
 
 	QDomNode get_state(QDomDocument doc);
 	int set_state( const QDomNode & node );
