@@ -131,7 +131,7 @@ void BusSelectorDialog::accept()
 	QList<QListWidgetItem *>  list = busesListWidget->selectedItems();
 	
 	if (list.size()) {
-		m_currentTrack->set_bus_in(list.at(0)->text().toAscii());
+		m_currentTrack->set_bus_in(list.at(0)->text().toLatin1());
 		
 		if (radioBoth->isChecked()) {
 			m_currentTrack->set_capture_left_channel(true);
@@ -148,7 +148,7 @@ void BusSelectorDialog::accept()
 	list = busesListWidgetPlayback->selectedItems();
 	
 	if (list.size()) {
-		m_currentTrack->set_bus_out(list.at(0)->text().toAscii());
+		m_currentTrack->set_bus_out(list.at(0)->text().toLatin1());
 		
 /*		if (radioBothPlayback->isChecked()) {
 			m_currentTrack->set_playback_left_channel(true);
